@@ -21,7 +21,7 @@
 #include "triggerconfigwidget.h"
 #include "../engine/texturehelper.h"
 #include "settings.h"
-
+#include <QIcon>
 #include <QTimer>
 
 //BEGIN Palapeli::TriggerComboBox
@@ -71,10 +71,10 @@ Palapeli::ConfigDialog::ConfigDialog(QWidget* parent)
 	setupSolutionAreaComboBox();
 
 	addPage(generalPage, i18n("General settings"))->
-				setIcon(KIcon( QLatin1String( "configure" )));
+				setIcon(QIcon::fromTheme( QStringLiteral( "configure" )));
 	//setup page "Mouse interaction"
 	addPage(m_triggerPage, i18n("Mouse interaction"))->
-				setIcon(KIcon( QLatin1String( "input-mouse" )));
+				setIcon(QIcon::fromTheme( QStringLiteral( "input-mouse" )));
 	connect(m_triggerPage, SIGNAL(associationsChanged()),
 			       SLOT(updateButtons()));
 }
@@ -137,10 +137,10 @@ void Palapeli::ConfigDialog::solutionAreaChange(int index)
 	// index setting if .kcfg says "Int", but it does not officially support
 	// the QComboBox type.
 	Settings::setSolutionArea(index);
-	Settings::self()->writeConfig();
+	Settings::self()->save();
 }
 
 //END Palapeli::ConfigDialog
 
-#include "configdialog.moc"
-#include "configdialog_p.moc"
+
+//
